"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BLEND_MODES = exports.LAYER_TYPE_CLIPPING_MASK = exports.LAYER_TYPE_ELLIPSE = exports.LAYER_TYPE_POLYGON = exports.LAYER_TYPE_TEXT = exports.LAYER_TYPE_LAYER = void 0;
const debug_1 = __importDefault(require("../../debug"));
const align_1 = __importDefault(require("./align"));
const blur_1 = __importDefault(require("./blur"));
const brightness_1 = __importDefault(require("./brightness"));
const circularMask_1 = __importDefault(require("./circularMask"));
const duplicate_1 = __importDefault(require("./duplicate"));
const exportTo_1 = __importDefault(require("./exportTo"));
const grayscale_1 = __importDefault(require("./grayscale"));
const hue_1 = __importDefault(require("./hue"));
const exportILA_1 = __importDefault(require("./ila/exportILA"));
const getILAData_1 = __importDefault(require("./ila/getILAData"));
const importILA_1 = __importDefault(require("./ila/importILA"));
const invert_1 = __importDefault(require("./invert"));
const move_1 = __importDefault(require("./move"));
const rasterize_1 = __importDefault(require("./rasterize"));
const reflect_1 = __importDefault(require("./reflect"));
const remove_1 = __importDefault(require("./remove"));
const resize_1 = __importDefault(require("./resize"));
const resizeBy_1 = __importDefault(require("./resizeBy"));
const rotate_1 = __importDefault(require("./rotate"));
const saturation_1 = __importDefault(require("./saturation"));
const setBlendMode_1 = __importDefault(require("./setBlendMode"));
const setOpacity_1 = __importDefault(require("./setOpacity"));
const translate_1 = __importDefault(require("./translate"));
const translateBy_1 = __importDefault(require("./translateBy"));
exports.LAYER_TYPE_LAYER = 0;
exports.LAYER_TYPE_TEXT = 1;
exports.LAYER_TYPE_POLYGON = 2;
exports.LAYER_TYPE_ELLIPSE = 3;
exports.LAYER_TYPE_CLIPPING_MASK = 4;
exports.BLEND_MODES = ["normal", "darken", "multiply", "colorBurn", "lighten", "screen", "colorDodge", "linearDodge", "overlay", "softLight", "hardLight", "difference", "exclusion"];
class BaseLayer {
    constructor(baseLayerData, document) {
        this.document = document;
        this.name = baseLayerData.name;
        this.left = baseLayerData.left || 0;
        this.top = baseLayerData.top || 0;
        this._edits = [];
        this.opacity = 100;
        this.blendMode = "normal";
        this.setDebugMode(baseLayerData.debugMode || false);
        if (document)
            document.addLayer(this, baseLayerData.position);
    }
    get position() {
        return this.document ? this.document.layers.findIndex((l) => l === this) : 0;
    }
    setName(name) {
        this.name = name;
    }
    duplicate(name, position, debugMode) {
        return duplicate_1.default(this, name, position, debugMode);
    }
    move(position, relative) {
        return move_1.default(this, position, relative);
    }
    translate(left, top) {
        return translate_1.default(this, left, top);
    }
    translateBy(x, y) {
        return translateBy_1.default(this, x, y);
    }
    align(alignOptions) {
        return align_1.default(this, alignOptions);
    }
    rotate(degrees) {
        return rotate_1.default(this, degrees);
    }
    resize(width, height) {
        return resize_1.default(this, width, height);
    }
    resizeBy(width, height, scale) {
        return resizeBy_1.default(this, width, height, scale);
    }
    reflect(direction) {
        return reflect_1.default(this, direction);
    }
    setOpacity(opacity) {
        return setOpacity_1.default(this, opacity);
    }
    setBlendMode(blendMode) {
        return setBlendMode_1.default(this, blendMode);
    }
    hue(degrees) {
        return hue_1.default(this, degrees);
    }
    saturation(amount) {
        return saturation_1.default(this, amount);
    }
    brightness(amount) {
        return brightness_1.default(this, amount);
    }
    grayscale() {
        return grayscale_1.default(this);
    }
    invert() {
        return invert_1.default(this);
    }
    blur(sigma) {
        return blur_1.default(this, sigma);
    }
    circularMask(name, keepSource) {
        return circularMask_1.default(this, name, keepSource);
    }
    remove() {
        remove_1.default(this);
    }
    rasterize() {
        return rasterize_1.default(this);
    }
    exportTo(format, exportType, pathOrWithMetadata) {
        return exportTo_1.default(this, format, exportType, pathOrWithMetadata);
    }
    exportILA(exportType, path) {
        return exportILA_1.default(this, exportType, path);
    }
    static importILA(pathOrBuffer, assetsDirectory) {
        return importILA_1.default(pathOrBuffer, assetsDirectory);
    }
    _getILAData(assets) {
        return getILAData_1.default(this, assets);
    }
    setDebugMode(debugMode) {
        this.debugMode = debugMode;
    }
    _debug(info) {
        debug_1.default(info, this);
    }
}
exports.default = BaseLayer;
