/// <reference types="node" />
import { BlendMode, Edit, LayerType, LAYER_TYPE_CLIPPING_MASK, LAYER_TYPE_ELLIPSE, LAYER_TYPE_LAYER, LAYER_TYPE_POLYGON, LAYER_TYPE_TEXT, ShapeLayerType } from "../../../internal";
export declare type ILAData = ILALayerData | ILATextData | ILAPolygonData | ILAEllipseData | ILAClippingMaskData;
export interface ILABaseData {
    name: string;
    type: LayerType;
    left: number;
    top: number;
    edits: Edit[];
    opacity: number;
    blendMode: BlendMode;
}
export interface ILALayerData extends ILABaseData {
    type: typeof LAYER_TYPE_LAYER;
    inputImageID: number;
}
export interface ILATextData extends ILABaseData {
    type: typeof LAYER_TYPE_TEXT;
    text: string;
    font?: string;
    fontSize: number;
    fontWeight?: string;
    color: string;
    maxWidth: number;
}
export interface ILAShapeData extends ILABaseData {
    type: ShapeLayerType;
    width: number;
    height: number;
    fill?: string;
    stroke?: string;
    strokeWidth?: number;
}
export interface ILAPolygonData extends ILAShapeData {
    type: typeof LAYER_TYPE_POLYGON;
    sides: number;
}
export interface ILAEllipseData extends ILAShapeData {
    type: typeof LAYER_TYPE_ELLIPSE;
}
export interface ILAClippingMaskData extends ILABaseData {
    type: typeof LAYER_TYPE_CLIPPING_MASK;
    mask: ILAData;
    source: ILAData;
}
export interface ILAAsset {
    image: string | Buffer;
    svg: boolean;
}
