"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const path_1 = require("path");
const sharp_1 = __importDefault(require("sharp"));
const tar_1 = __importDefault(require("tar"));
const tmp_promise_1 = __importDefault(require("tmp-promise"));
async function exportILA(baseLayer, exportType, path) {
    const tempDirectory = await tmp_promise_1.default.dir({
        unsafeCleanup: true
    });
    await fs_1.promises.mkdir(`${tempDirectory.path}/data`);
    const assets = [];
    const ilaData = baseLayer._getILAData(assets);
    await fs_1.promises.writeFile(`${tempDirectory.path}/data/data.json`, JSON.stringify(ilaData));
    await fs_1.promises.mkdir(`${tempDirectory.path}/data/assets`);
    for (let i = 0; i < assets.length; i++) {
        const asset = assets[i];
        if (typeof asset.image === "string")
            await fs_1.promises.copyFile(asset.image, `${tempDirectory.path}/data/assets/${i + 1}${path_1.extname(asset.image)}`);
        else if (asset.svg)
            await fs_1.promises.writeFile(`${tempDirectory.path}/data/assets/${i + 1}.svg`, asset.image.toString());
        else
            await sharp_1.default(asset.image).toFormat("png").toFile(`${tempDirectory.path}/data/assets/${i + 1}.png`);
    }
    await tar_1.default.create({
        file: path || `${tempDirectory.path}/layer.ila`,
        gzip: true,
        cwd: tempDirectory.path
    }, ["data/"]);
    if (exportType === "file") {
        await tempDirectory.cleanup();
        if (!path)
            throw new Error("Path must be specified if exportType is 'file'");
        return undefined;
    }
    const exported = await fs_1.promises.readFile(`${tempDirectory.path}/layer.ila`);
    await tempDirectory.cleanup();
    return exported;
}
exports.default = exportILA;
