"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const internal_1 = require("../../../internal");
function getILAData(baseLayer, assets) {
    if (baseLayer instanceof internal_1.TextLayer)
        return {
            name: baseLayer.name,
            type: internal_1.LAYER_TYPE_TEXT,
            left: baseLayer.left,
            top: baseLayer.top,
            edits: baseLayer._edits,
            opacity: baseLayer.opacity,
            blendMode: baseLayer.blendMode,
            text: baseLayer.text,
            font: baseLayer.font,
            fontSize: baseLayer.fontSize,
            fontWeight: baseLayer.fontWeight,
            color: baseLayer.color,
            maxWidth: baseLayer.maxWidth
        };
    else if (baseLayer instanceof internal_1.Polygon)
        return {
            name: baseLayer.name,
            type: internal_1.LAYER_TYPE_POLYGON,
            left: baseLayer.left,
            top: baseLayer.top,
            edits: baseLayer._edits,
            opacity: baseLayer.opacity,
            blendMode: baseLayer.blendMode,
            width: baseLayer.width,
            height: baseLayer.height,
            fill: baseLayer.fill,
            stroke: baseLayer.stroke,
            strokeWidth: baseLayer.strokeWidth,
            sides: baseLayer.sides
        };
    else if (baseLayer instanceof internal_1.Ellipse)
        return {
            name: baseLayer.name,
            type: internal_1.LAYER_TYPE_ELLIPSE,
            left: baseLayer.left,
            top: baseLayer.top,
            edits: baseLayer._edits,
            opacity: baseLayer.opacity,
            blendMode: baseLayer.blendMode,
            width: baseLayer.width,
            height: baseLayer.height,
            fill: baseLayer.fill,
            stroke: baseLayer.stroke,
            strokeWidth: baseLayer.strokeWidth
        };
    else if (baseLayer instanceof internal_1.ClippingMask)
        return {
            name: baseLayer.name,
            type: internal_1.LAYER_TYPE_CLIPPING_MASK,
            left: baseLayer.left,
            top: baseLayer.top,
            edits: baseLayer._edits,
            opacity: baseLayer.opacity,
            blendMode: baseLayer.blendMode,
            mask: baseLayer.mask._getILAData(assets),
            source: baseLayer.source._getILAData(assets)
        };
    else {
        const layer = baseLayer;
        assets.push({
            image: layer.image,
            svg: layer._svg
        });
        return {
            name: layer.name,
            type: internal_1.LAYER_TYPE_LAYER,
            left: layer.left,
            top: layer.top,
            edits: layer._edits,
            opacity: layer.opacity,
            blendMode: layer.blendMode,
            inputImageID: assets.length
        };
    }
}
exports.default = getILAData;
