"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const tar_1 = __importDefault(require("tar"));
const tmp_promise_1 = __importDefault(require("tmp-promise"));
const parseILAData_1 = __importDefault(require("../../BaseLayer/ila/parseILAData"));
async function importILA(pathOrBuffer, assetsDirectory) {
    const tempDirectory = await tmp_promise_1.default.dir({
        unsafeCleanup: true
    });
    if (typeof pathOrBuffer === "string")
        await fs_1.promises.copyFile(pathOrBuffer, `${tempDirectory.path}/layer.ila`);
    else
        await fs_1.promises.writeFile(`${tempDirectory.path}/layer.ila`, pathOrBuffer);
    await tar_1.default.extract({
        file: `${tempDirectory.path}/layer.ila`,
        cwd: tempDirectory.path
    });
    const data = JSON.parse((await fs_1.promises.readFile(`${tempDirectory.path}/data/data.json`)).toString());
    const assetNames = (await fs_1.promises.readdir(`${tempDirectory.path}/data/assets`)).sort((a, b) => parseInt(a) - parseInt(b));
    let assets = [];
    if (assetsDirectory)
        for (let asset of assetNames) {
            await fs_1.promises.copyFile(`${tempDirectory.path}/data/assets/${asset}`, `${assetsDirectory}/${asset}`);
            assets.push(`${assetsDirectory}/${asset}`);
        }
    else
        for (let asset of assetNames) {
            const image = await fs_1.promises.readFile(`${tempDirectory.path}/data/assets/${asset}`);
            assets.push(asset.endsWith(".svg") ? image.toString() : image);
        }
    const layer = await parseILAData_1.default(data, assets);
    await tempDirectory.cleanup();
    return layer;
}
exports.default = importILA;
