/// <reference types="node" />
import { AnyLayer, ClippingMask, ClippingMaskData, Ellipse, EllipseData, Layer, LayerData, Polygon, PolygonData, TextLayer, TextLayerData } from "../../internal";
import { ExportTypes, Format, Output, PathOrWithMetadataOptions } from "../BaseLayer/exportTo";
export interface DocumentData {
    name?: string;
    width: number;
    height: number;
    debugMode?: boolean;
}
export default class Document {
    name: string;
    width: number;
    height: number;
    layers: AnyLayer[];
    debugMode: boolean;
    constructor(documentData: DocumentData);
    setName(name: string): void;
    createLayer(layerData: LayerData): Promise<Layer>;
    createPolygon(polygonData: PolygonData): Polygon;
    createEllipse(ellipseData: EllipseData): Ellipse;
    createTextLayer(textLayerData: TextLayerData): TextLayer;
    createClippingMask(clippingMaskData: ClippingMaskData): ClippingMask;
    addLayer(layer: AnyLayer, position?: number): void;
    getLayer(nameOrIndex: string | number): AnyLayer | undefined;
    mergeLayers(name: string, layers?: Array<AnyLayer | string | number>, copy?: boolean): Promise<Layer>;
    exportTo<ExportType extends ExportTypes, PathOrWithMetadata extends PathOrWithMetadataOptions = false>(format: Format, exportType: ExportType, pathOrWithMetadata?: PathOrWithMetadata): Promise<Output<ExportType, PathOrWithMetadata>>;
    exportILD<ExportType extends ExportTypes, Path extends string>(exportType: ExportType, path?: Path): Promise<Output<ExportType, Path>>;
    static importILD(pathOrBuffer: string | Buffer, assetsDirectory?: string): Promise<Document>;
    setDebugMode(debugMode: boolean): void;
    _debug(info: string): void;
}
