"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const debug_1 = __importDefault(require("../../debug"));
const addLayer_1 = __importDefault(require("./addLayer"));
const createClippingMask_1 = __importDefault(require("./createClippingMask"));
const createEllipse_1 = __importDefault(require("./createEllipse"));
const createLayer_1 = __importDefault(require("./createLayer"));
const createPolygon_1 = __importDefault(require("./createPolygon"));
const createTextLayer_1 = __importDefault(require("./createTextLayer"));
const exportTo_1 = __importDefault(require("./exportTo"));
const exportILD_1 = __importDefault(require("./ild/exportILD"));
const importILD_1 = __importDefault(require("./ild/importILD"));
const mergeLayers_1 = __importDefault(require("./mergeLayers"));
class Document {
    constructor(documentData) {
        this.name = documentData.name || "Unnamed Document";
        this.width = documentData.width;
        this.height = documentData.height;
        this.layers = [];
        this.setDebugMode(documentData.debugMode || false);
    }
    setName(name) {
        this.name = name;
    }
    createLayer(layerData) {
        return createLayer_1.default(this, layerData);
    }
    createPolygon(polygonData) {
        return createPolygon_1.default(this, polygonData);
    }
    createEllipse(ellipseData) {
        return createEllipse_1.default(this, ellipseData);
    }
    createTextLayer(textLayerData) {
        return createTextLayer_1.default(this, textLayerData);
    }
    createClippingMask(clippingMaskData) {
        return createClippingMask_1.default(this, clippingMaskData);
    }
    addLayer(layer, position) {
        addLayer_1.default(this, layer, position);
    }
    getLayer(nameOrIndex) {
        if (typeof nameOrIndex === "string")
            return this.layers.find((l) => l.name === nameOrIndex);
        else if (typeof nameOrIndex === "number")
            return this.layers[nameOrIndex];
    }
    mergeLayers(name, layers, copy) {
        return mergeLayers_1.default(this, name, layers, copy);
    }
    exportTo(format, exportType, pathOrWithMetadata) {
        return exportTo_1.default(this, format, exportType, pathOrWithMetadata);
    }
    exportILD(exportType, path) {
        return exportILD_1.default(this, exportType, path);
    }
    static importILD(pathOrBuffer, assetsDirectory) {
        return importILD_1.default(pathOrBuffer, assetsDirectory);
    }
    setDebugMode(debugMode) {
        this.debugMode = debugMode;
    }
    _debug(info) {
        debug_1.default(info, this);
    }
}
exports.default = Document;
