"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const tar_1 = __importDefault(require("tar"));
const tmp_promise_1 = __importDefault(require("tmp-promise"));
const internal_1 = require("../../../internal");
const parseILAData_1 = __importDefault(require("../../BaseLayer/ila/parseILAData"));
async function importILD(pathOrBuffer, assetsDirectory) {
    const tempDirectory = await tmp_promise_1.default.dir({
        unsafeCleanup: true
    });
    if (typeof pathOrBuffer === "string")
        await fs_1.promises.copyFile(pathOrBuffer, `${tempDirectory.path}/document.ild`);
    else
        await fs_1.promises.writeFile(`${tempDirectory.path}/document.ild`, pathOrBuffer);
    await tar_1.default.extract({
        file: `${tempDirectory.path}/document.ild`,
        cwd: tempDirectory.path
    });
    const data = JSON.parse((await fs_1.promises.readFile(`${tempDirectory.path}/data/data.json`)).toString());
    if (typeof data.name !== "string")
        throw new Error("Error parsing Illustra file");
    if (typeof data.width !== "number")
        throw new Error("Error parsing Illustra file");
    if (typeof data.height !== "number")
        throw new Error("Error parsing Illustra file");
    if (!(data.layers instanceof Array))
        throw new Error("Error parsing Illustra file");
    const document = new internal_1.Document({
        name: data.name,
        width: data.width,
        height: data.height
    });
    const assetNames = (await fs_1.promises.readdir(`${tempDirectory.path}/data/assets`)).sort((a, b) => parseInt(a) - parseInt(b));
    let assets = [];
    if (assetsDirectory)
        for (let asset of assetNames) {
            await fs_1.promises.copyFile(`${tempDirectory.path}/data/assets/${asset}`, `${assetsDirectory}/${asset}`);
            assets.push(`${assetsDirectory}/${asset}`);
        }
    else
        for (let asset of assetNames) {
            const image = await fs_1.promises.readFile(`${tempDirectory.path}/data/assets/${asset}`);
            assets.push(asset.endsWith(".svg") ? image.toString() : image);
        }
    for (let layer of data.layers)
        document.addLayer(await parseILAData_1.default(layer, assets));
    await tempDirectory.cleanup();
    return document;
}
exports.default = importILD;
